Module blaxel.core.sandbox.client.models.success_response
=========================================================

Classes
-------

`SuccessResponse(message: str, path: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>)`
:   Attributes:
        message (str):  Example: File created successfully.
        path (Union[Unset, str]):  Example: /path/to/file.
    
    Method generated by attrs for class SuccessResponse.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `message: str`
    :

    `path: blaxel.core.sandbox.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :